@@ -19,16 +19,16 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const Application = imports.application;
-const HVT = imports.hvt;
-const Time = imports.time;
-const TransitOptions = imports.transitOptions;
-const TransitPlan = imports.transitPlan;
+import {Application} from './application.js';
+import * as HVT from './hvt.js';
+import * as Time from './time.js';
+import {TransitOptions} from './transitOptions.js';
+import * as TransitPlan from './transitPlan.js';
 
 // in org.gnome.desktop.interface
 const CLOCK_FORMAT_KEY = 'clock-format';
@@ -40,24 +40,11 @@ const _timeFormat = new Intl.DateTimeFormat([], { hour:     '2-digit',
                                                   minute:   '2-digit',
                                                   hour12:   clockFormat === '12h' });
 
-var TransitOptionsPanel = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/transit-options-panel.ui',
-    InternalChildren: ['transitTimeOptionsComboBox',
-                       'transitTimeEntry',
-                       'transitDateButton',
-                       'transitDateCalendar',
-                       'transitParametersMenuButton',
-                       'busCheckButton',
-                       'tramCheckButton',
-                       'trainCheckButton',
-                       'subwayCheckButton',
-                       'ferryCheckButton',
-                       'airplaneCheckButton']
-}, class TransitOptionsPanel extends Gtk.Grid {
+export class TransitOptionsPanel extends Gtk.Grid {
 
-    _init(params) {
+    constructor(params) {
+        super(params);
         this._query = Application.routeQuery;
-        super._init(params);
         this._initTransitOptions();
     }
 
@@ -68,7 +55,7 @@ var TransitOptionsPanel = GObject.registerClass({
         this._transitTimeOptionsComboBox.active_id = 'leaveNow';
         this._timeSelected = false;
         this._dateSelected = false;
-        this._lastOptions = new TransitOptions.TransitOptions();
+        this._lastOptions = new TransitOptions();
     }
 
     _initTransitOptions() {
@@ -76,17 +63,19 @@ var TransitOptionsPanel = GObject.registerClass({
             this._onTransitTimeOptionsComboboxChanged.bind(this));
         this._transitTimeEntry.connect('activate',
             this._onTransitTimeEntryActivated.bind(this));
+        this._eventControllerFocus = new Gtk.EventControllerFocus();
+        this._transitTimeEntry.add_controller(this._eventControllerFocus);
         /* trigger an update of the query time as soon as focus leave the time
          * entry, to allow the user to enter a time before selecting start
          * and destination without having to press enter */
-        this._transitTimeEntry.connect('focus-out-event',
+        this._eventControllerFocus.connect('leave',
             this._onTransitTimeEntryActivated.bind(this));
-        this._transitDateButton.popover.get_child().connect('day-selected-double-click',
+        this._transitDateButton.popover.get_child().connect('day-selected',
             this._onTransitDateCalenderDaySelected.bind(this));
-        this._transitDateButton.connect('toggled',
-            this._onTransitDateButtonToogled.bind(this));
-        this._transitParametersMenuButton.connect('toggled',
-            this._onTransitParametersToggled.bind(this))
+        this._transitDateButton.popover.connect('closed',
+            this._onTransitDateClosed.bind(this));
+        this._transitParametersMenuButton.popover.connect('closed',
+            this._onTransitParametersClosed.bind(this))
     }
 
     _onTransitTimeOptionsComboboxChanged() {
@@ -138,8 +127,7 @@ var TransitOptionsPanel = GObject.registerClass({
     _updateTransitDateButton(date) {
         let calendar = this._transitDateButton.popover.get_child();
 
-        calendar.select_month(date.get_month() - 1, date.get_year());
-        calendar.select_day(date.get_day_of_month());
+        calendar.select_day(date);
         this._transitDateButton.label =
             /*
              * Translators: this is a format string giving the equivalent to
@@ -166,13 +154,12 @@ var TransitOptionsPanel = GObject.registerClass({
         }
     }
 
-    _onTransitDateButtonToogled() {
-        if (!this._transitDateButton.active)
-            this._onTransitDateCalenderDaySelected();
+    _onTransitDateClosed() {
+        this._onTransitDateCalenderDaySelected();
     }
 
     _createTransitOptions() {
-        let options = new TransitOptions.TransitOptions();
+        let options = new TransitOptions();
         let busSelected = this._busCheckButton.active;
         let tramSelected = this._tramCheckButton.active;
         let trainSelected = this._trainCheckButton.active;
@@ -201,14 +188,27 @@ var TransitOptionsPanel = GObject.registerClass({
         return options;
     }
 
-    _onTransitParametersToggled() {
-        if (!this._transitParametersMenuButton.active) {
-            let options = this._createTransitOptions();
+    _onTransitParametersClosed() {
+        let options = this._createTransitOptions();
 
-            if (!TransitOptions.equals(options, this._lastOptions)) {
-                this._query.transitOptions = options;
-                this._lastOptions = options;
-            }
+        if (!TransitOptions.equals(options, this._lastOptions)) {
+            this._query.transitOptions = options;
+            this._lastOptions = options;
         }
     }
- });
+ }
+
+ GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/transit-options-panel.ui',
+    InternalChildren: ['transitTimeOptionsComboBox',
+                       'transitTimeEntry',
+                       'transitDateButton',
+                       'transitDateCalendar',
+                       'transitParametersMenuButton',
+                       'busCheckButton',
+                       'tramCheckButton',
+                       'trainCheckButton',
+                       'subwayCheckButton',
+                       'ferryCheckButton',
+                       'airplaneCheckButton']
+}, TransitOptionsPanel);
